Summarize result object in the format required for upload to Movebank
FLightR2Movebank(Result, alpha = 0.5, filename = NULL)FLightR result object obtained from run.particle.filter
coverage of the credible intervals for now only two options: 0.95 or 0.5.
if NULL data.frame in TAGS format will be returned otherwise .csv file in TAGS format will be written
NULL if filename is provided or Movebank formatted dataframe.
This function accepts FLightR results object.