this function converts combines twilights detected in twGeos with raw data and writes them down in TAGS format that can be easily read by get.tags.data
twGeos2TAGS(raw, twl, threshold, filename = NULL)original data - dataframe with two columns first column must contain time and second measured light levels
twilights object from preprocess.light function
threshold value used for twilight definition in preprocess.light
if NULL data.frame in TAGS format will be returned otherwise .csv file in TAGS format will be written
NULL if filename is provided or TAGS formatted dataframe.
TAGS format returned or written as .csv by this function is a dataframe with columns
datetime date and time in ISO 8601 format e.g. 2013-06-16T00:00:11.000Z
light light value measured by tag
twilight assigned by the software numeric indication of whether the record belongs to sunrise (1), sunset (2) or none of those (0)
excluded indication of whether a twilight was excluded during manual inspection (logical, TRUE | FALSE)
interp indication of whether the light value at twilight was interpolated (logical, TRUE | FALSE)
The fields excluded and interp may have values of TRUE only for twilight > 0.